#include <cvidef.h>

/*= Q7760 Optical Network Analyzer Include File =============================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __avq7760_HEADER
#define __avq7760_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)
#define VI_ERROR_INSTR_PARAMETER16              (_VI_ERROR+0x3FFC0810L)
#define VI_ERROR_INSTR_PARAMETER17              (_VI_ERROR+0x3FFC0811L)  
/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define AVQ7760_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF0L)

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC avq7760_Initialize (ViRsrc resourceName, ViBoolean IDQuery,
                                       ViBoolean resetDevice,
                                       ViSession *instrumentHandle);

ViStatus _VI_FUNC avq7760_Set_Function (ViSession instrumentHandle,
                                        ViBoolean measMode, ViInt16 measFormat,
                                        ViBoolean levelDisplay);

ViStatus _VI_FUNC avq7760_Set_Advance (ViSession instrumentHandle,
                                       ViReal64 fiberIndex,
                                       ViBoolean autoLambdaLength,
                                       ViReal64 lambda_withLength,
                                       ViReal64 lambda4, ViReal64 lambda2,
                                       ViBoolean freeRotate,
                                       ViBoolean calFiberLength);

ViStatus _VI_FUNC avq7760_Set_Domain (ViSession instrumentHandle,
                                      ViBoolean domain);

ViStatus _VI_FUNC avq7760_Set_CenterSpan (ViSession instrumentHandle,
										  ViBoolean domain,
                                          ViReal64 center, ViReal64 span);

ViStatus _VI_FUNC avq7760_Set_StartStop (ViSession instrumentHandle,
										 ViBoolean domain,
                                         ViReal64 start, ViReal64 stop);

ViStatus CVIFUNC avq7760_Set_WavelenFreq (ViSession instrumentHandle,
                                          ViInt16 setMode, ViReal64 value,
                                          ViBoolean XAxisUnit);

ViStatus CVIFUNC avq7760_Set_ExpDisplay (ViSession instrumentHandle,
                                         ViBoolean expansionDisplay);

ViStatus CVIFUNC avq7760_Set_CursorCenter (ViSession instrumentHandle);

ViStatus _VI_FUNC avq7760_Set_LevelScale (ViSession instrumentHandle,
                                          ViBoolean atScl, ViInt16 lvScl,
                                          ViReal64 refLvl);

ViStatus _VI_FUNC avq7760_Set_ScaleConversion (ViSession instrumentHandle,
                                               ViInt16 scaleConversion,
                                               ViReal64 fiberLength);

ViStatus _VI_FUNC avq7760_Set_ModulationFreq (ViSession instrumentHandle,
                                              ViBoolean autoModulationFrequency,
                                              ViReal64 modulationFrequency);

ViStatus _VI_FUNC avq7760_Set_Display (ViSession instrumentHandle,
                                       ViBoolean dualDisplay,
                                       ViBoolean superimpose, ViBoolean actUL,
                                       ViBoolean actLR, ViBoolean grid,
                                       ViBoolean bothMeasurement,
                                       ViBoolean exchange,
                                       ViBoolean paste, ViBoolean erase);

ViStatus _VI_FUNC avq7760_Set_LimitLine (ViSession instrumentHandle,
                                         ViBoolean limitLine,
                                         ViInt16 readPattern);

ViStatus CVIFUNC avq7760_DisplayReport (ViSession instrumentHandle,
                                        ViBoolean displayReport,
                                        ViString comment, ViString ID1,
                                        ViString ID2, ViString ID3,
                                        ViString fileName, ViReal64 startRambda,
                                        ViReal64 stopRambda,
                                        ViReal64 rambdaResolution,
                                        ViReal64 referenceRambda,
                                        ViBoolean executeReportPrint);

ViStatus _VI_FUNC avq7760_Average (ViSession instrumentHandle, ViBoolean average,
                                   ViInt16 averageCount);

ViStatus _VI_FUNC avq7760_Unwrap (ViSession instrumentHandle, ViBoolean unwrap,
                                  ViReal64 threshold);

ViStatus _VI_FUNC avq7760_Smoothing (ViSession instrumentHandle,
									 ViBoolean domain,
                                     ViReal64 smoothingWindow, ViBoolean smoothing);

ViStatus _VI_FUNC avq7760_Sweep (ViSession instrumentHandle, ViBoolean sweepMode,
                                 ViBoolean fixedMode, ViBoolean select,
                                 ViInt16 dataPoints, ViReal64 lambdaResolution);

ViStatus _VI_FUNC avq7760_MeasMode (ViSession instrumentHandle, ViInt16 measMode);

ViStatus _VI_FUNC avq7760_Fit (ViSession instrumentHandle, ViBoolean fitting,
                               ViInt16 fittingMode, ViBoolean measDataDisplay,
                               ViBoolean measDataLine, ViBoolean partialFit);

ViStatus _VI_FUNC avq7760_Sensitivity (ViSession instrumentHandle,
                                       ViInt16 sensitivity);

ViStatus _VI_FUNC avq7760_LambdaComp (ViSession instrumentHandle,
                                      ViBoolean lambdaCompensation,
                                      ViInt16 wavelengthMeterType);

ViStatus _VI_FUNC avq7760_Set_LevelOffset (ViSession instrumentHandle,
                                           ViReal64 reflectLevelOffset,
                                           ViReal64 transmitLevelOffset);

ViStatus _VI_FUNC avq7760_SaveReference (ViSession instrumentHandle,
                                         ViBoolean saveAs);

ViStatus _VI_FUNC avq7760_Normalize (ViSession instrumentHandle,
                                     ViBoolean reflect, ViBoolean transmit);

ViStatus _VI_FUNC avq7760_Exe_Calibration (ViSession instrumentHandle,
                                           ViInt16 calibration);

ViStatus _VI_FUNC avq7760_Measure (ViSession instrumentHandle, ViInt16 measure);

ViStatus _VI_FUNC avq7760_Cursor (ViSession instrumentHandle, 
								  ViBoolean domain, ViBoolean cursor,
                                  ViBoolean cursorX1, ViReal64 cursorX1Position,
                                  ViBoolean cursorX2, ViReal64 cursorX2Position,
                                  ViBoolean cursorL1, ViReal64 cursorL1Position,
                                  ViBoolean cursorL2, ViReal64 cursorL2Position);

ViStatus CVIFUNC avq7760_Mode (ViSession instrumentHandle, ViInt16 mode,
                               ViBoolean bandWidth, ViBoolean bandWidthMode,
                               ViReal64 xdBParameter, ViReal64 ydBParameter,
                               ViReal64 kparameter);

ViStatus _VI_FUNC avq7760_Save_MeasData (ViSession instrumentHandle,
                                         ViBoolean medium, ViInt16 memoryNumber,
                                         ViString savedName,
                                         ViBoolean unitNormalize,
                                         ViBoolean dataKind,
                                         ViBoolean measFormat);

ViStatus _VI_FUNC avq7760_Save_Panel (ViSession instrumentHandle,
                                      ViBoolean medium, ViInt16 memoryNumber,
                                      ViString savedName);

ViStatus _VI_FUNC avq7760_Save_Bitmap (ViSession instrumentHandle);

ViStatus _VI_FUNC avq7760_Load_MeasData (ViSession instrumentHandle,
                                         ViBoolean medium, ViInt16 memoryNumber,
                                         ViString fileName);

ViStatus _VI_FUNC avq7760_Load_Panel (ViSession instrumentHandle,
                                      ViBoolean medium, ViInt16 memoryNumber,
                                      ViString fileName);

ViStatus CVIFUNC avq7760_ColorPattern (ViSession instrumentHandle,
                                       ViInt16 colorPattern);

ViStatus CVIFUNC avq7760_Printer (ViSession instrumentHandle,
                                  ViInt16 printerType, ViBoolean execute);

ViStatus CVIFUNC avq7760_Label (ViSession instrumentHandle, ViString label);

ViStatus CVIFUNC avq7760_Buzzer (ViSession instrumentHandle, ViBoolean beep,
                                 ViBoolean warning, ViBoolean quietBeep);

ViStatus CVIFUNC avq7760_Set_Clock (ViSession instrumentHandle, ViInt16 year,
                                    ViInt16 month, ViInt16 day, ViInt16 hour,
                                    ViInt16 minute);

ViStatus CVIFUNC avq7760_Disp_Clock (ViSession instrumentHandle,
                                     ViBoolean display);

ViStatus CVIFUNC avq7760_SRQ (ViSession instrumentHandle, ViBoolean SRQOut);

ViStatus CVIFUNC avq7760_Mask_STB (ViSession instrumentHandle, ViInt16 maskValue);

ViStatus CVIFUNC avq7760_Clear_STB (ViSession instrumentHandle);

ViStatus CVIFUNC avq7760_Header (ViSession instrumentHandle, ViBoolean header);

ViStatus CVIFUNC avq7760_Set_Terminator (ViSession instrumentHandle,
                                         ViInt16 terminator);

ViStatus CVIFUNC avq7760_Set_DataSepa (ViSession instrumentHandle,
                                       ViInt16 dataSeparator);

ViStatus CVIFUNC avq7760_Sel_DataOut (ViSession instrumentHandle,
                                      ViInt16 dataFormat, ViBoolean screen);

ViStatus CVIFUNC avq7760_ASCII_Waveform (ViSession instrumentHandle,
                                         ViBoolean screen, ViBoolean axis,
                                         ViInt16 *dataNumber,
                                         ViReal64 waveformData[]);

ViStatus CVIFUNC avq7760_BIN16_Waveform (ViSession instrumentHandle,
                                         ViBoolean screen, ViBoolean axis,
                                         ViInt16 *dataNumber,
                                         ViInt16 waveformData[]);

ViStatus CVIFUNC avq7760_BIN64Float_Waveform (ViSession instrumentHandle,
                                              ViBoolean screen, ViBoolean axis,
                                              ViInt16 *dataNumber,
                                              ViReal64 waveformData[]);

ViStatus CVIFUNC avq7760_BIN32Float_Waveform (ViSession instrumentHandle,
                                              ViBoolean screen, ViBoolean axis,
                                              ViInt16 *dataNumber,
                                              float waveformData[]);

ViStatus CVIFUNC avq7760_FiberLengthData (ViSession instrumentHandle,
                                          ViReal64 *fiberLength);

ViStatus CVIFUNC avq7760_PeakSearchData (ViSession instrumentHandle,
                                         ViReal64 *position, ViReal64 *peakLevel);

ViStatus CVIFUNC avq7760_CursorData (ViSession instrumentHandle,
                                     ViInt16 cursorMode, ViReal64 *data1,
                                     ViReal64 *data2, ViReal64 *data3,
                                     ViReal64 *data4, ViReal64 *data5,
                                     ViReal64 *data6);

ViStatus CVIFUNC avq7760_HalfWidthData (ViSession instrumentHandle,
                                        ViReal64 *center, ViReal64 *halfWidth,
                                        ViInt16 *numberofPeaks);

ViStatus CVIFUNC avq7760_ClockData (ViSession instrumentHandle, ViInt16 *year,
                                    ViInt16 *month, ViInt16 *day, ViInt16 *hour,
                                    ViInt16 *minute, ViInt16 *second);

ViStatus CVIFUNC avq7760_Preset (ViSession instrumentHandle);

ViStatus _VI_FUNC avq7760_SelfTest (ViSession instrumentHandle,
                                     ViInt16 *selfTestResult);

ViStatus _VI_FUNC avq7760_ErrorMessage (ViSession instrumentHandle,
                                         ViStatus statusCode, ViChar message[]);

ViStatus _VI_FUNC avq7760_Reset (ViSession instrumentHandle);

ViStatus _VI_FUNC avq7760_Query_TypeRevision (ViSession instrumentHandle,
                                               ViChar instrumentDriverRevision[],
                                               ViChar firmwareType[],
                                               ViChar firmwareSystemCode[],
                                               ViChar firmwareRevision[]);

ViStatus CVIFUNC avq7760_close (ViSession instrSession);

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
